# inspired from:

# https://python-packaging-user-guide.readthedocs.org/en/latest/single_source_version/
# https://github.com/pypa/warehouse/blob/master/warehouse/__about__.py

__name__ = 'blis'
__title__ = 'blis'
__version__ = '0.0.5'
__summary__ = 'Cython bindings for Blis linear algebra'
__uri__ = 'https://github.com/spacy-io/cython-blis'
__author__ = 'Matthew Honnibal'
__email__ = 'honnibal@gmail.com'
__license__ = 'MIT'
__release__ = True
